@@ -26,10 +26,6 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#ifdef HAVE_DBUS
-#include <dbus/dbus-glib-bindings.h>
-#include <gdk/gdkx.h>
-#endif
 #ifdef HAVE_INTROSPECTION
 #include <girepository.h>
 #endif
@@ -55,9 +51,7 @@ static EogStartupFlags flags;
 static gboolean fullscreen = FALSE;
 static gboolean slide_show = FALSE;
 static gboolean disable_gallery = FALSE;
-#if HAVE_DBUS
 static gboolean force_new_instance = FALSE;
-#endif
 static gchar **startup_files = NULL;
 
 static gboolean
@@ -66,7 +60,7 @@ _print_version_and_exit (const gchar *option_name,
 			 gpointer data,
 			 GError **error)
 {
-	g_print("%s %s\n", _("Eye of GNOME Image Viewer"), VERSION);
+	g_print("%s %s\n", _("GNOME Image Viewer"), VERSION);
 	exit (EXIT_SUCCESS);
 	return TRUE;
 }
@@ -76,12 +70,9 @@ static const GOptionEntry goption_options[] =
 	{ "fullscreen", 'f', 0, G_OPTION_ARG_NONE, &fullscreen, N_("Open in fullscreen mode"), NULL  },
 	{ "disable-gallery", 'g', 0, G_OPTION_ARG_NONE, &disable_gallery, N_("Disable image gallery"), NULL  },
 	{ "slide-show", 's', 0, G_OPTION_ARG_NONE, &slide_show, N_("Open in slideshow mode"), NULL  },
-#if HAVE_DBUS
 	{ "new-instance", 'n', 0, G_OPTION_ARG_NONE, &force_new_instance, N_("Start a new instance instead of reusing an existing one"), NULL },
-#endif
 	{ "version", 0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
 	  _print_version_and_exit, N_("Show the application's version"), NULL},
-	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &startup_files, NULL, N_("[FILE…]") },
 	{ NULL }
 };
 
@@ -98,90 +89,6 @@ set_startup_flags (void)
     flags |= EOG_STARTUP_SLIDE_SHOW;
 }
 
-static void
-load_files (void)
-{
-	GSList *files = NULL;
-
-	files = eog_util_string_array_to_list ((const gchar **) startup_files, TRUE);
-
-	eog_application_open_uri_list (EOG_APP,
-				       files,
-				       GDK_CURRENT_TIME,
-				       flags,
-				       NULL);
-
-	g_slist_foreach (files, (GFunc) g_free, NULL);
-	g_slist_free (files);
-}
-
-#ifdef HAVE_DBUS
-static gboolean
-load_files_remote (void)
-{
-	GError *error = NULL;
-	DBusGConnection *connection;
-	DBusGProxy *remote_object;
-	gboolean result = TRUE;
-	GdkDisplay *display;
-	guint32 timestamp;
-	gchar **files;
-
-	display = gdk_display_get_default ();
-
-	timestamp = gdk_x11_display_get_user_time (display);
-	connection = dbus_g_bus_get (DBUS_BUS_STARTER, &error);
-
-	if (connection == NULL) {
-		g_warning ("%s", error->message);
-		g_error_free (error);
-
- 		return FALSE;
- 	}
-
- 	files = eog_util_string_array_make_absolute (startup_files);
-
- 	remote_object = dbus_g_proxy_new_for_name (connection,
- 						   "org.gnome.eog.ApplicationService",
-						   "/org/gnome/eog/Eog",
-						   "org.gnome.eog.Application");
-
- 	if (!files) {
- 		if (!dbus_g_proxy_call (remote_object, "OpenWindow", &error,
- 					G_TYPE_UINT, timestamp,
- 					G_TYPE_UCHAR, flags,
- 					G_TYPE_INVALID,
- 					G_TYPE_INVALID)) {
- 			g_warning ("%s", error->message);
- 			g_clear_error (&error);
-
- 			result = FALSE;
- 		}
- 	} else {
- 		if (!dbus_g_proxy_call (remote_object, "OpenUris", &error,
- 					G_TYPE_STRV, files,
- 					G_TYPE_UINT, timestamp,
- 					G_TYPE_UCHAR, flags,
- 					G_TYPE_INVALID,
- 					G_TYPE_INVALID)) {
- 			g_warning ("%s", error->message);
- 			g_clear_error (&error);
-
-			result = FALSE;
- 		}
-
- 		g_strfreev (files);
- 	}
-
- 	g_object_unref (remote_object);
- 	dbus_g_connection_unref (connection);
-
- 	gdk_notify_startup_complete ();
-
- 	return result;
-}
-#endif /* HAVE_DBUS */
-
 int
 main (int argc, char **argv)
 {
@@ -198,7 +105,7 @@ main (int argc, char **argv)
 
 	gtk_rc_parse (EOG_DATA_DIR G_DIR_SEPARATOR_S "gtkrc");
 
-	ctx = g_option_context_new (NULL);
+	ctx = g_option_context_new (_("[FILE…]"));
 	g_option_context_add_main_entries (ctx, goption_options, PACKAGE);
 	/* Option groups are free'd together with the context 
 	 * Using gtk_get_option_group here initializes gtk during parsing */
@@ -226,15 +133,6 @@ main (int argc, char **argv)
 
 	set_startup_flags ();
 
-#ifdef HAVE_DBUS
-	if (!force_new_instance &&
-	    !eog_application_register_service (EOG_APP)) {
-		if (load_files_remote ()) {
-			return 0;
-		}
-	}
-#endif /* HAVE_DBUS */
-
 #ifdef HAVE_EXEMPI
  	xmp_init();
 #endif
@@ -251,18 +149,24 @@ main (int argc, char **argv)
                                            EOG_DATA_DIR G_DIR_SEPARATOR_S "icons");
 
 	gtk_window_set_default_icon_name ("eog");
-	g_set_application_name (_("Eye of GNOME Image Viewer"));
+	g_set_application_name (_("Image Viewer"));
 
 	settings = gtk_settings_get_default ();
 	g_object_set (G_OBJECT (settings),
 	              "gtk-application-prefer-dark-theme", TRUE,
 	              NULL);
 
-	load_files ();
-
 	gdk_threads_enter ();
 
-	gtk_main ();
+	EOG_APP->flags = flags;
+	if (force_new_instance) {
+		GApplicationFlags app_flags = g_application_get_flags (G_APPLICATION (EOG_APP));
+		app_flags |= G_APPLICATION_NON_UNIQUE;
+		g_application_set_flags (G_APPLICATION (EOG_APP), app_flags);
+	}
+
+	g_application_run (G_APPLICATION (EOG_APP), argc, argv);
+	g_object_unref (EOG_APP);
 
 	gdk_threads_leave ();
 
